@@ -2,14 +2,15 @@ use super::mitre::{MitreTactics, MitreTechniques};
 use std::collections::BTreeMap;
 use super::SiemLog;
 use super::dataset::{SiemDataset, SiemDatasetType};
-use super::actuator::ActuatorRequest;
+use super::task::{SiemTask};
 use serde::Serialize;
+use dyn_clone::{clone_trait_object, DynClone};
 
 /// Common rule format to create rock solid rules
 /// The rule must be stateless
-pub trait SolidRule {
+pub trait SolidRule : DynClone + Send{
     /// Checks if the log matches this rule. It can return an alert and/or an action to be executed by the SOAR
-    fn match_log(&self, log: &SiemLog) -> Option<(Option<SiemAlert>, Option<ActuatorRequest>)>;
+    fn match_log(&self, log: &SiemLog) -> Option<(Option<SiemAlert>, Option<SiemTask>)>;
     /// Name of the rule
     fn name(&self) -> &'static str;
     /// Name of the Service applied to match this rule
@@ -27,6 +28,7 @@ pub trait SolidRule {
     /// List of datasets needed by this rule
     fn datasets(&self) -> &'static Vec<SiemDatasetType>;
 }
+clone_trait_object!(SolidRule);
 
 #[derive(Serialize, Debug, Clone)]
 pub enum AlertSeverity {
@@ -76,7 +78,7 @@ mod tests {
         static ref EXAMPLE_RULE_DATASETS : Vec<SiemDatasetType> = vec!();
         static ref RULE_STATE : Arc<Mutex<BTreeMap<String, Vec<i64>>>> = Arc::new(Mutex::new(BTreeMap::new()));
     }
-
+    #[derive(Clone)]
     struct ExampleRule {
         templates : BTreeMap<&'static str,&'static str>,
         mapping : BTreeMap<&'static str,&'static str>,
@@ -92,7 +94,7 @@ mod tests {
         }
     }
     impl SolidRule for ExampleRule {
-        fn match_log(&self, log: &SiemLog) -> Option<(Option<SiemAlert>, Option<ActuatorRequest>)> {
+        fn match_log(&self, log: &SiemLog) -> Option<(Option<SiemAlert>, Option<SiemTask>)> {
             let lang = self.mapping.get(log.tenant()).unwrap_or(&"en");
             let description = self.templates.get(lang).unwrap_or(&"Alert default example").to_string();
             return Some((Some(SiemAlert {
@@ -131,7 +133,7 @@ mod tests {
             return &EXAMPLE_RULE_DATASETS
         }
     }
-
+    #[derive(Clone)]
     struct StatefulRule {
         templates : BTreeMap<&'static str,&'static str>,
         mapping : BTreeMap<&'static str,&'static str>,
@@ -145,7 +147,7 @@ mod tests {
         }
     }
     impl SolidRule for StatefulRule {
-        fn match_log(&self, log: &SiemLog) -> Option<(Option<SiemAlert>, Option<ActuatorRequest>)> {
+        fn match_log(&self, log: &SiemLog) -> Option<(Option<SiemAlert>, Option<SiemTask>)> {
             let lang = self.mapping.get(log.tenant()).unwrap_or(&"en");
             let description = self.templates.get(lang).unwrap_or(&"Alert for user $domain\\$username. $number login errors in less than a minute");
 
