@@ -216,6 +216,11 @@ pub enum SiemTaskType {
         Cow<'static, str>,
         BTreeMap<Cow<'static, str>, Cow<'static, str>>,
     ),
+    /// Log query and log parameters
+    LOG_QUERY(
+        String,
+        BTreeMap<Cow<'static, str>, Cow<'static, str>>,
+    ),
     /// Remediate a list of emails. List of parameters
     REMEDIATE_EMAILS(BTreeMap<Cow<'static, str>, Cow<'static, str>>),
     /// Report IP, email to abuse mail. Needed provider name and parameters
@@ -350,9 +355,9 @@ pub enum SiemFunctionResponse {
     FILTER_DOMAIN(Result<Cow<'static, str>, Cow<'static, str>>),
     /// (Email, Comment)
     FILTER_EMAIL_SENDER(Result<Cow<'static, str>, Cow<'static, str>>),
-    /// List of UseCases
-    LIST_USE_CASES(Vec<&'static SiemUseCase>),
-    GET_USE_CASE(Option<&'static SiemUseCase>),
+    /// List of UseCases: (Name,Description)
+    LIST_USE_CASES(Vec<(Cow<'static, str>,Cow<'static, str>)>),
+    GET_USE_CASE(Option<(Cow<'static, str>,Cow<'static, str>)>),
     LIST_RULES(Vec<(&'static str, &'static str)>),
     GET_RULE(Option<(&'static str, &'static str)>),
     LIST_DATASETS(Vec<Cow<'static, str>>),
